[tor-commits] [tor/master] Remove 0.2.9 from git scripts

dgoulet at torproject.org dgoulet at torproject.org
Tue Jan 14 19:06:05 UTC 2020


commit c0dd214c8a6075499368e2be79d01205be715f97
Author: rl1987 <rl1987 at sdf.lonestar.org>
Date:   Mon Dec 30 12:41:08 2019 +0700

    Remove 0.2.9 from git scripts
---
 scripts/git/git-merge-forward.sh | 21 ++++++---------------
 scripts/git/git-pull-all.sh      |  7 -------
 scripts/git/git-push-all.sh      |  9 +--------
 scripts/git/git-setup-dirs.sh    |  7 -------
 4 files changed, 7 insertions(+), 37 deletions(-)

diff --git a/scripts/git/git-pull-all.sh b/scripts/git/git-pull-all.sh
index 9e12b565b..6e02093ad 100755
--- a/scripts/git/git-pull-all.sh
+++ b/scripts/git/git-pull-all.sh
@@ -58,14 +58,12 @@ TOR_WKT_NAME=${TOR_WKT_NAME:-"tor-wkt"}
 #
 # First set of arrays are the maint-* branch and then the release-* branch.
 # New arrays need to be in the WORKTREE= array else they aren't considered.
-MAINT_029=( "maint-0.2.9" "$GIT_PATH/$TOR_WKT_NAME/maint-0.2.9" )
 MAINT_035=( "maint-0.3.5" "$GIT_PATH/$TOR_WKT_NAME/maint-0.3.5" )
 MAINT_040=( "maint-0.4.0" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.0" )
 MAINT_041=( "maint-0.4.1" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.1" )
 MAINT_042=( "maint-0.4.2" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.2" )
 MAINT_MASTER=( "master" "$GIT_PATH/$TOR_MASTER_NAME" )
 
-RELEASE_029=( "release-0.2.9" "$GIT_PATH/$TOR_WKT_NAME/release-0.2.9" )
 RELEASE_035=( "release-0.3.5" "$GIT_PATH/$TOR_WKT_NAME/release-0.3.5" )
 RELEASE_040=( "release-0.4.0" "$GIT_PATH/$TOR_WKT_NAME/release-0.4.0" )
 RELEASE_041=( "release-0.4.1" "$GIT_PATH/$TOR_WKT_NAME/release-0.4.1" )
@@ -78,13 +76,11 @@ ORIGIN_PATH="$GIT_PATH/$TOR_MASTER_NAME"
 
 # SC2034 -- shellcheck thinks that these are unused.  We know better.
 ACTUALLY_THESE_ARE_USED=<<EOF
-${MAINT_029[0]}
 ${MAINT_035[0]}
 ${MAINT_040[0]}
 ${MAINT_041[0]}
 ${MAINT_042[0]}
 ${MAINT_MASTER[0]}
-${RELEASE_029[0]}
 ${RELEASE_035[0]}
 ${RELEASE_040[0]}
 ${RELEASE_041[0]}
@@ -98,9 +94,6 @@ EOF
 # List of all worktrees to work on. All defined above. Ordering is important.
 # Always the maint-* branch first then the release-*.
 WORKTREE=(
-  MAINT_029[@]
-  RELEASE_029[@]
-
   MAINT_035[@]
   RELEASE_035[@]
 
diff --git a/scripts/git/git-push-all.sh b/scripts/git/git-push-all.sh
index 293df0342..671fed2c1 100755
--- a/scripts/git/git-push-all.sh
+++ b/scripts/git/git-push-all.sh
@@ -21,7 +21,7 @@ function usage()
   echo "   -r: push to remote-name, rather than the default upstream remote."
   echo "       (default: $DEFAULT_UPSTREAM_REMOTE, current: $UPSTREAM_REMOTE)"
   echo "   -t: test branch mode: push test branches to remote-name. Pushes"
-  echo "       branches prefix_029, prefix_035, ... , prefix_master."
+  echo "       branches prefix_035, prefix_040,  ... , prefix_master."
   echo "       (default: push maint-*, release-*, and master)"
   echo "   -s: push branches whose tips match upstream maint, release, or"
   echo "       master branches. The default is to skip these branches,"
@@ -175,7 +175,6 @@ if [ "$DEFAULT_UPSTREAM_REMOTE" != "$UPSTREAM_REMOTE" ]; then
     "$DEFAULT_UPSTREAM_REMOTE"/{release,maint}-0.4.1 \
     "$DEFAULT_UPSTREAM_REMOTE"/{release,maint}-0.4.0 \
     "$DEFAULT_UPSTREAM_REMOTE"/{release,maint}-0.3.5 \
-    "$DEFAULT_UPSTREAM_REMOTE"/{release,maint}-0.2.9 \
     )
 fi
 
@@ -185,7 +184,6 @@ UPSTREAM_BRANCHES=$(echo \
   "$UPSTREAM_REMOTE"/{release,maint}-0.4.1 \
   "$UPSTREAM_REMOTE"/{release,maint}-0.4.0 \
   "$UPSTREAM_REMOTE"/{release,maint}-0.3.5 \
-  "$UPSTREAM_REMOTE"/{release,maint}-0.2.9 \
   )
 
 ########################
@@ -198,7 +196,6 @@ PUSH_BRANCHES=$(echo \
   {release,maint}-0.4.1 \
   {release,maint}-0.4.0 \
   {release,maint}-0.3.5 \
-  {release,maint}-0.2.9 \
   )
 
 if [ -z "$TEST_BRANCH_PREFIX" ]; then
@@ -212,12 +209,9 @@ if [ -z "$TEST_BRANCH_PREFIX" ]; then
     {release,maint}-0.4.1 \
     {release,maint}-0.4.0 \
     {release,maint}-0.3.5 \
-    {release,maint}-0.2.9 \
     )
 else
 
-  # Test branch mode: merge to maint only, and create a new branch for 0.2.9
-  #
   # List of branches to push. Ordering is not important.
   PUSH_BRANCHES=" \
     ${TEST_BRANCH_PREFIX}_master \
@@ -225,7 +219,6 @@ else
     ${TEST_BRANCH_PREFIX}_041 \
     ${TEST_BRANCH_PREFIX}_040 \
     ${TEST_BRANCH_PREFIX}_035 \
-    ${TEST_BRANCH_PREFIX}_029 \
     "
 fi
 
diff --git a/scripts/git/git-setup-dirs.sh b/scripts/git/git-setup-dirs.sh
index b7a37a04e..20a148204 100755
--- a/scripts/git/git-setup-dirs.sh
+++ b/scripts/git/git-setup-dirs.sh
@@ -96,14 +96,12 @@ GITHUB_PUSH=${TOR_GITHUB_PUSH:-"No_Pushing_To_GitHub"}
 #
 # First set of arrays are the maint-* branch and then the release-* branch.
 # New arrays need to be in the WORKTREE= array else they aren't considered.
-MAINT_029=( "maint-0.2.9" "$GIT_PATH/$TOR_WKT_NAME/maint-0.2.9" )
 MAINT_035=( "maint-0.3.5" "$GIT_PATH/$TOR_WKT_NAME/maint-0.3.5" )
 MAINT_040=( "maint-0.4.0" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.0" )
 MAINT_041=( "maint-0.4.1" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.1" )
 MAINT_042=( "maint-0.4.2" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.2" )
 MAINT_MASTER=( "master" "$GIT_PATH/$TOR_MASTER_NAME" )
 
-RELEASE_029=( "release-0.2.9" "$GIT_PATH/$TOR_WKT_NAME/release-0.2.9" )
 RELEASE_035=( "release-0.3.5" "$GIT_PATH/$TOR_WKT_NAME/release-0.3.5" )
 RELEASE_040=( "release-0.4.0" "$GIT_PATH/$TOR_WKT_NAME/release-0.4.0" )
 RELEASE_041=( "release-0.4.1" "$GIT_PATH/$TOR_WKT_NAME/release-0.4.1" )
@@ -116,13 +114,11 @@ ORIGIN_PATH="$GIT_PATH/$TOR_MASTER_NAME"
 
 # SC2034 -- shellcheck thinks that these are unused.  We know better.
 ACTUALLY_THESE_ARE_USED=<<EOF
-${MAINT_029[0]}
 ${MAINT_035[0]}
 ${MAINT_040[0]}
 ${MAINT_041[0]}
 ${MAINT_042[0]}
 ${MAINT_MASTER[0]}
-${RELEASE_029[0]}
 ${RELEASE_035[0]}
 ${RELEASE_040[0]}
 ${RELEASE_041[0]}
@@ -166,9 +162,6 @@ done
 ###########################
 
 WORKTREE=(
-  MAINT_029[@]
-  RELEASE_029[@]
-
   MAINT_035[@]
   RELEASE_035[@]
 





More information about the tor-commits mailing list
diff --git a/scripts/git/git-merge-forward.sh b/scripts/git/git-merge-forward.sh
index a6df47959..c6e02294c 100755
--- a/scripts/git/git-merge-forward.sh
+++ b/scripts/git/git-merge-forward.sh
@@ -11,8 +11,8 @@ function usage()
   echo "   -n: dry run mode"
   echo "       (default: run commands)"
   echo "   -t: test branch mode: create new branches from the commits checked"
-  echo "       out in each maint directory. Call these branches prefix_029,"
-  echo "       prefix_035, ... , prefix_master."
+  echo "       out in each maint directory. Call these branches prefix_035,"
+  echo "       prefix_040, ... , prefix_master."
   echo "       (default: merge forward maint-*, release-*, and master)"
   echo "   -u: in test branch mode, if a prefix_* branch already exists,"
   echo "       skip creating that branch. Use after a merge error, to"
@@ -89,8 +89,6 @@ TOR_WKT_NAME=${TOR_WKT_NAME:-"tor-wkt"}
 # Only used in test branch mode
 # There is no previous branch to merge forward, so the second and fifth items
 # must be blank ("")
-MAINT_029_TB=( "maint-0.2.9" "" "$GIT_PATH/$TOR_WKT_NAME/maint-0.2.9" \
-    "_029" "")
 # Used in maint/release merge and test branch modes
 MAINT_035=( "maint-0.3.5" "maint-0.2.9" "$GIT_PATH/$TOR_WKT_NAME/maint-0.3.5" \
     "_035" "_029")
@@ -103,7 +101,6 @@ MAINT_042=( "maint-0.4.2" "maint-0.4.1" "$GIT_PATH/$TOR_WKT_NAME/maint-0.4.2" \
 MAINT_MASTER=( "master" "maint-0.4.2" "$GIT_PATH/$TOR_MASTER_NAME" \
     "_master" "_042")
 
-RELEASE_029=( "release-0.2.9" "maint-0.2.9" "$GIT_PATH/$TOR_WKT_NAME/release-0.2.9" )
 RELEASE_035=( "release-0.3.5" "maint-0.3.5" "$GIT_PATH/$TOR_WKT_NAME/release-0.3.5" )
 RELEASE_040=( "release-0.4.0" "maint-0.4.0" "$GIT_PATH/$TOR_WKT_NAME/release-0.4.0" )
 RELEASE_041=( "release-0.4.1" "maint-0.4.1" "$GIT_PATH/$TOR_WKT_NAME/release-0.4.1" )
@@ -116,13 +113,11 @@ ORIGIN_PATH="$GIT_PATH/$TOR_MASTER_NAME"
 
 # SC2034 -- shellcheck thinks that these are unused.  We know better.
 ACTUALLY_THESE_ARE_USED=<<EOF
-${MAINT_029_TB[0]}
 ${MAINT_035[0]}
 ${MAINT_040[0]}
 ${MAINT_041[0]}
 ${MAINT_042[0]}
 ${MAINT_MASTER[0]}
-${RELEASE_029[0]}
 ${RELEASE_035[0]}
 ${RELEASE_040[0]}
 ${RELEASE_041[0]}
@@ -139,7 +134,7 @@ DRY_RUN=0
 
 # Controlled by the -t <test-branch-prefix> option. The test branch base
 # name option makes git-merge-forward.sh create new test branches:
 # <tbbn>_029, <tbbn>_035, ... , <tbbn>_master, and merge forward.
 TEST_BRANCH_PREFIX=
 
 # Controlled by the -u option. The use existing option checks for existing
@@ -180,8 +175,6 @@ if [ -z "$TEST_BRANCH_PREFIX" ]; then
   # List of all worktrees to work on. All defined above. Ordering is important.
   # Always the maint-* branch BEFORE then the release-*.
   WORKTREE=(
-    RELEASE_029[@]
-
     MAINT_035[@]
     RELEASE_035[@]
 
@@ -199,10 +192,8 @@ if [ -z "$TEST_BRANCH_PREFIX" ]; then
 
 else
 
-  # Test branch mode: merge to maint only, and create a new branch for 0.2.9
+  # Test branch mode: merge to maint only
   WORKTREE=(
-    MAINT_029_TB[@]
-
     MAINT_035[@]
 
     MAINT_040[@]
@@ -427,9 +418,9 @@ for ((i=0; i<COUNT; i++)); do
   fi
   # Merge the previous branch into the target branch
   # Merge Forward Example:
-  #   merge maint-0.2.9 into maint-0.3.5.
+  #   merge maint-0.3.5 into maint-0.4.0.
   # Test Branch Example:
-  #   merge bug99999_029 into bug99999_035.
+  #   merge bug99999_035 into bug99999_040.
   # Skip the merge if the previous branch does not exist
   # (there's nothing to merge forward into the oldest test branch)
   if [ "$target_previous" ]; then
@@ -139,7 +134,7 @@ DRY_RUN=0
 # Controlled by the -t <test-branch-prefix> option. The test branch base
 # name option makes git-merge-forward.sh create new test branches:
-# <tbbn>_029, <tbbn>_035, ... , <tbbn>_master, and merge forward.
+# <tbbn>_035, <tbbn>_040, ... , <tbbn>_master, and merge forward.
 TEST_BRANCH_PREFIX=
 